tendril.inventory.guidelines package
====================================

Module contents
---------------

.. automodule:: tendril.inventory.guidelines
    :members:
    :undoc-members:
    :show-inheritance:
